@@ -6,17 +6,19 @@
 action=$1
 filetype=$2
 
-[ -n "${MC_XDG_OPEN}" ] || MC_XDG_OPEN="xdg-open"
+if [ -n "$DISPLAY" ]; then
+    [ -n "${MC_XDG_OPEN}" ] || MC_XDG_OPEN="xdg-open"
+fi
 
 do_view_action() {
     filetype=$1
 
     case "${filetype}" in
     *)
-        if which mplayer >/dev/null 2>&1; then
+        if command -v mplayer >/dev/null 2>&1; then
             mplayer -identify -vo null -ao null -frames 0 "${MC_EXT_FILENAME}" 2>&1 | \
                 sed -n 's/^ID_//p'
-        elif which mpv_identify.sh >/dev/null 2>&1; then
+        elif command -v mpv_identify.sh >/dev/null 2>&1; then
             mpv_identify.sh "${MC_EXT_FILENAME}"
         else
             echo "Please install either mplayer or mpv[tools] to get information for this file"
@@ -28,24 +30,17 @@ do_view_action() {
 do_open_action() {
     filetype=$1
 
-    if which mpv >/dev/null 2>&1; then
-        PLAYER=mpv
-    elif which mplayer >/dev/null 2>&1; then
-        PLAYER=mplayer
+    if command -v mpv >/dev/null 2>&1; then
+        PLAYER="mpv --really-quiet"
     else
-        echo "Please install either mplayer or mpv to play this file"
-        return
+        PLAYER="mplayer -really-quiet"
     fi
 
-    case "${filetype}" in
-    *)
-        if [ -n "$DISPLAY" ]; then
-            ($PLAYER "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
-        else
-            $PLAYER -vo null "${MC_EXT_FILENAME}"
-        fi
-        ;;
-    esac
+    if [ -n "$DISPLAY" ]; then
+        ($PLAYER "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
+    else
+        $PLAYER -vo null "${MC_EXT_FILENAME}"
+    fi
 }
 
 case "${action}" in
